@@ -12,7 +12,7 @@ FFMPEG_REGEX = re.compile(r'^(?:-)?(?:(?:(?:(\d\d{1}):){1}([0-5]?\d):){1}([0-5]?
 # FFMPEG 形如01:23:45.67或-01:23:45.67
 DLP_REGEX = re.compile(r'^(?:-)?(?:(?:(?:(\d\d{1}):){1}([0-5]?\d):){1}([0-5]?\d):){1}([0-2][0-4]\d{1}){1}$')
 # DLP 形如01:23:45:102或-01:23:45:102（末三位取值范围是0-249）
-FCPX_REGEX = re.compile(r'^(?:-)?(\d+)[/]?(\d+)?s$')
+FCPX_REGEX = re.compile(r'^(?:-)?(\d+)[/](\d+)?s$')
 # FCPX 形如1/24s或-1/24s s可有可无
 FRAME_REGEX = re.compile(r'^(-?\d+?)f?$')
 # 帧号 形如1234f或-1234f f可有可无
